@@ -4,6 +4,7 @@ from typing import List
 from typing import Optional
 from typing import Literal
 from functools import cached_property
+from pydantic import Field
 
 from tendril.utils.pydantic import TendrilTBaseModel
 
@@ -39,7 +40,8 @@ logger = log.get_logger(__name__, log.DEFAULT)
 
 
 class InterestBaseCreateTModel(TendrilTBaseModel):
-    name: str
+    name: str = Field(..., max_length=255)
+    descriptive_name : Optional[str] = Field(..., max_length=255)
     type: Literal['interest']
     info: dict
 
@@ -60,19 +62,30 @@ class InterestBase(object):
     model = InterestModel
     tmodel_create = InterestBaseCreateTModel
     tmodel = InterestBaseTModel
+    additional_fields = []
 
-    def __init__(self, name, must_create=False, can_create=True, session=None):
+    def __init__(self, name, info=None, must_create=False,
+                 can_create=True, session=None):
         self._name = None
+        self._descriptive_name = None
+        self._info = None
         self._model_instance: InterestModel = None
         self._status: InterestLifecycleStatus = None
         if isinstance(name, InterestModel):
+            if must_create:
+                raise AttributeError("Expected a name, not an object")
             self._model_instance = name
         else:
             self._name = name
+            self._info = info or {}
             self._commit_to_db(must_create=must_create,
                                can_create=can_create,
                                session=session)
 
+    @property
+    def type_name(self):
+        return self.model.type_name
+
     @property
     def name(self):
         if self._name:
@@ -81,15 +94,31 @@ class InterestBase(object):
             return self._model_instance.name
 
     @property
-    def type_name(self):
-        return self.model.type_name
+    def descriptive_name(self):
+        if self._descriptive_name:
+            return self._descriptive_name
+        else:
+            return self._model_instance.descriptive_name
+
+    @with_db
+    def set_descriptive_name(self, value, session=None):
+        self._descriptive_name = value
+        self._commit_to_db(session=session)
 
     @property
     def ident(self):
         return f"{self.__class__.__name__} {self.name}"
 
-    def _info(self):
-        return {}
+    @property
+    def info(self):
+        if self._info is not None:
+            return self._info
+        else:
+            return self._model_instance.info
+
+    @property
+    def id(self):
+        return self._model_instance.id
 
     @property
     def status(self):
@@ -111,18 +140,12 @@ class InterestBase(object):
             if not len(users):
                 raise RequiredRoleNotPresent(role, self.id, self.name)
         if self.model.role_spec.activation_requirements['parent_required']:
-            pass
+            if not len(self.parents(limited=False, session=session)):
+                raise RequiredParentNotPresent(self.id, self.name)
+        logger.info(f"Activating {self.model.type_name} Interest {self.id} {self.name}")
         self._model_instance.status = InterestLifecycleStatus.ACTIVE
         session.add(self._model_instance)
 
-    @property
-    def id(self):
-        return self._model_instance.id
-
-    @property
-    def info(self):
-        return self._info()
-
     @property
     def roles(self):
         return self._model_instance.role_spec.roles
@@ -133,8 +156,8 @@ class InterestBase(object):
 
     @with_db
     @require_state(InterestLifecycleStatus.ACTIVE,
-                   exceptions=[(('status', 'NEW'), ('role', 'self.model.role_spec.apex_role'))])
-    @require_permission('add_member', specifier='role',
+                   exceptions=[(('status', 'NEW'),)])
+    @require_permission('add_member', specifier='role', required=False,
                         preprocessor=normalize_role_name, strip_auth=False,
                         exceptions=[(('status', 'NEW'), ('role', 'self.model.role_spec.apex_role'))])
     def assign_role(self, role=None, user=None, reference=None, auth_user=None, session=None):
@@ -179,11 +202,7 @@ class InterestBase(object):
 
     @with_db
     def get_role_accepted_users(self, role, session=None):
-        users = []
-        for d_role in self.model.role_spec.get_accepted_roles(role):
-            for user in get_role_users(self.id, d_role, session=session):
-                users.append(user)
-        return users
+        return self.memberships(role=role, session=session)
 
     @with_db
     def check_user_access(self, user, action, session=None):
@@ -213,10 +232,11 @@ class InterestBase(object):
         return master
 
     @with_db
-    @require_permission('read_members', strip_auth=False,
+    @require_permission('read_members', strip_auth=False, required=False,
                         specifier='role', preprocessor=normalize_role_name)
     def memberships(self, role=None, session=None, auth_user=None,
                     include_effective=True, include_inherited=True):
+        # TODO Consider building this once and caching it.
         if not role:
             rv = {}
             session.add(self._model_instance)
@@ -332,7 +352,10 @@ class InterestBase(object):
             'id': self.id,
             'info': self.info,
             'status': self.status,
+            'descriptive_name': self.descriptive_name,
         }
+        for field in self.additional_fields:
+            rv[field] = getattr(self, field)
         if include_roles or include_permissions:
             user_roles = self.get_user_effective_roles(auth_user, session=session)
         if include_roles:
@@ -354,6 +377,10 @@ class InterestBase(object):
                   'must_create': must_create,
                   'can_create': can_create,
                   'session': session}
+        if self._descriptive_name:
+            kwargs['descriptive_name'] = self._descriptive_name
+        for field in self.additional_fields:
+            kwargs[field] = getattr(self, field)
         if self._model_instance:
             kwargs['id'] = self.id
         self._model_instance = upsert_interest(**kwargs)
